from .region import FloatingRegionBySelector, RegionBySelector
from .selenium_check_settings import FrameLocator, SeleniumCheckSettings
from .target import Target

__all__ = (
    "Target",
    "SeleniumCheckSettings",
    "FrameLocator",
    "RegionBySelector",
    "FloatingRegionBySelector",
)
